@@ -1,7 +1,7 @@
 package cointop
 
 import (
-	"github.com/miguelmota/cointop/pkg/ui"
+	"github.com/cointop-sh/cointop/pkg/ui"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -10,8 +10,7 @@ type MenuView = ui.View
 
 // NewMenuView returns a new menu view
 func NewMenuView() *MenuView {
-	var view *MenuView = ui.NewView("menu")
-	return view
+	return ui.NewView("menu")
 }
 
 // HideMenu hides the menu view
