@@ -4,9 +4,9 @@ import (
 	"fmt"
 	"unicode/utf8"
 
-	"github.com/miguelmota/cointop/pkg/open"
-	"github.com/miguelmota/cointop/pkg/pad"
-	"github.com/miguelmota/cointop/pkg/ui"
+	"github.com/cointop-sh/cointop/pkg/open"
+	"github.com/cointop-sh/cointop/pkg/pad"
+	"github.com/cointop-sh/cointop/pkg/ui"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -15,8 +15,7 @@ type StatusbarView = ui.View
 
 // NewStatusbarView returns a new statusbar view
 func NewStatusbarView() *StatusbarView {
-	var view *StatusbarView = ui.NewView("statusbar")
-	return view
+	return ui.NewView("statusbar")
 }
 
 // UpdateStatusbar updates the statusbar view
