@@ -5,11 +5,13 @@ import (
 	"fmt"
 	"os"
 	"strings"
+
+	log "github.com/sirupsen/logrus"
 )
 
 // ReadAPIKeyFromStdin reads the user inputed API from the stdin prompt
 func (ct *Cointop) ReadAPIKeyFromStdin(name string) (string, error) {
-	ct.debuglog("ReadAPIKeyFromStdin()")
+	log.Debug("ReadAPIKeyFromStdin()")
 	reader := bufio.NewReader(os.Stdin)
 	fmt.Printf("Enter %s API Key: ", name)
 	text, err := reader.ReadString('\n')
