@@ -5,7 +5,7 @@ import (
 	"net/url"
 	"strings"
 
-	"github.com/miguelmota/cointop/pkg/ui"
+	"github.com/cointop-sh/cointop/pkg/ui"
 	log "github.com/sirupsen/logrus"
 )
 
@@ -14,8 +14,7 @@ type TableView = ui.View
 
 // NewTableView returns a new table view
 func NewTableView() *TableView {
-	var view *TableView = ui.NewView("table")
-	return view
+	return ui.NewView("table")
 }
 
 const dots = "..."
@@ -98,7 +97,7 @@ func (ct *Cointop) UpdateTable() error {
 // GetTableCoinsSlice returns a slice of the table rows
 func (ct *Cointop) GetTableCoinsSlice() []*Coin {
 	log.Debug("GetTableCoinsSlice()")
-	sliced := []*Coin{}
+	var sliced []*Coin
 	start := ct.State.page * ct.State.perPage
 	end := start + ct.State.perPage
 	allCoins := ct.AllCoins()
