@@ -430,3 +430,11 @@ func getChartInterval(start, end int64) string {
 	}
 	return interval
 }
+
+// GetExchangeRate gets the current excange rate between two currencies
+func (s *Service) GetExchangeRate(convertFrom, convertTo string, cached bool) (float64, error) {
+	if convertFrom == convertTo {
+		return 1.0, nil
+	}
+	return 0, fmt.Errorf("unsupported currency conversion: %s => %s", convertFrom, convertTo)
+}
